==> koffice_2.1.1-0.tar.gz: koffice-2.1.1/kpresenter/part/animations/KPrAnimPar.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrAnimPar.h"

#include <KoXmlReader.h>
#include "KPrAnimationFactory.h"
#include "KPrAnimationCache.h"

KPrAnimPar::KPrAnimPar()
{
}

KPrAnimPar::~KPrAnimPar()
{
}

bool KPrAnimPar::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
{
    KoXmlElement e;
    forEachElement(e, element) {
        KPrAnimationBase * animation = KPrAnimationFactory::createAnimationFromOdf(e, context);
        if (animation) {
            m_animations.append(animation);
        }
    }
    return true;
}

void KPrAnimPar::saveOdf(KoShapeSavingContext &context) const
{
}

void KPrAnimPar::init(KPrAnimationCache *animationCache) const
{
    foreach(KPrAnimationBase *animation, m_animations) {
        animation->init(animationCache);
    }
}

==> koffice_2.2.0-1.tar.gz: koffice-2.2.0/kpresenter/part/animations/KPrAnimPar.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrAnimPar.h"

#include <KoXmlReader.h>
#include "KPrAnimationFactory.h"
#include "KPrAnimationCache.h"

#include <KoShapeLoadingContext.h>
#include <KoShapeSavingContext.h>

KPrAnimPar::KPrAnimPar()
{
}

KPrAnimPar::~KPrAnimPar()
{
}

bool KPrAnimPar::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
{
    KoXmlElement e;
    forEachElement(e, element) {
        KPrAnimationBase * animation = KPrAnimationFactory::createAnimationFromOdf(e, context);
        if (animation) {
            m_animations.append(animation);
        }
    }
    return true;
}

void KPrAnimPar::saveOdf(KoShapeSavingContext &context) const
{
    Q_UNUSED(context);
}

void KPrAnimPar::init(KPrAnimationCache *animationCache, int step) const
{
    foreach(KPrAnimationBase *animation, m_animations) {
        animation->init(animationCache, step);
    }
}
